# Contributing

Oh, hey! You found this repo quickly (or I might be working slowly!).

I'm still setting things up around here, so please check back later when I have some better guidelines for how you can 
help out. Feel free to reach out if you have any questions.

// haeger
